О компании | Интернет-магазин Fozzy
Description: Информация о компании
Keywords: о нас, информация

## О магазине

Делая покупки у нас, вы забываете о проблемах связанных с необходимостью посещать магазины в поисках нужных товаров, о длинных очередях в супермаркетах и гипермаркетах, автомобильных пробках по дороге в магазин, тяжелых сумках по дороге домой и можете быть уверены в высоком качестве всех товаров!

Желание быть лучшими – основной принцип нашей работы. Наша команда - это сплочённый коллектив, опытные специалисты во всех отделах и доброжелательность в работе с клиентами. Каждый покупатель для нас единственный и мы делаем все для удовлетворения его желаний.

Операторы Call-центра всегда готовы ответить на все интересующие вопросы, помочь с выбором.

Ассортимент магазина на данный момент более 10000 наименований товаров продовольственной группы, товаров для дома и офиса.

Заказы клиентов собираются и бережно упаковываются аккуратными, внимательными, терпеливыми сотрудниками.

## Режим работы:

- Мы работаем ежедневно c 9.00 до 18.00
- заказ можно оформить на сайте круглосуточно или позвонив в Call-центр c 9.00 до 18.00
- заказы доставляют в временных интервалах с 12.00 до 18.00 и с 18.00 до 21.00. При оформлении заказа до 11.00 доступна доставка в диапазонах с 12.00 до 17.30 и с 18.00 до 21.00. При оформлении заказа с 11.00 до 17.00 доступна доставка в диапазоне 18.00 до 21.00 или на следующий день.